Learn R Programming

SwimmeR (version 0.3.0)

course_convert: Swimming Course Convertor

Description

Used to convert times between Long Course Meters, Short Course Meters and Short Course Yards

Usage

course_convert(time, event, course, course_to)

Arguments

time

A time, or vector of times to convert. Can be in either seconds (numeric, 95.97) format or swim (character, "1:35.97") format

event

The event swum as "100 Fly", "200 IM", "400 Free", "50 Back", "200 Breast" etc.

course

The course in which the time was swum as "LCM", "SCM" or "SCY"

course_to

The course to convert the time to as "LCM", "SCM" or "SCY"

Value

returns the time for a specified event and course converted to a time for the specified course_to in swimming format

References

Uses the USA swimming age group method described here: https://support.teamunify.com/en/articles/260

Examples

Run this code
# NOT RUN {
course_convert(time = "1:35.93", event = "200 Free", course = "SCY", course_to = "LCM")
course_convert(time = 95.93, event = "200 Free", course = "scy", course_to = "lcm")
course_convert(time = 53.89, event = "100 Fly", course = "scm", course_to = "scy")

# }

Run the code above in your browser using DataLab