Used to convert times between Long Course Meters, Short Course Meters and Short Course Yards, returns data frame
course_convert_DF(time, event, course, course_to)course_convert_df(time, event, course, course_to)
This function returns a data frame including columns:
Time
Course
Course_To
Event
Time_Converted_sec
Time_Converted_mmss
A time, or vector of times to convert. Can be in either seconds
(numeric, 95.97) format or swim (character, "1:35.97") format
The event swum as "100 Fly", "200 IM", "400
Free", "50 Back", "200 Breast" etc.
The course in which the time was swum as "LCM",
"SCM" or "SCY"
The course to convert the time to as "LCM",
"SCM" or "SCY"
Uses the USA swimming age group method described here https://support.gomotionapp.com/en/articles/6457476-how-to-perform-course-conversion-factoring-of-times