Used to convert times between Long Course Meters, Short Course Meters and Short Course Yards
course_convert_helper(time, event, course, course_to, verbose = FALSE)returns the time for a specified event and
course converted to a time for the specified course_to in
swimming format OR a data frame containing columns
Time
Course
Course_To
Event
Time_Converted_sec
Time_Converted_mmss
depending on the value of verbose
A time, or vector of times to convert. Can be in either seconds
(numeric, 95.97) format or swim (character, "1:35.97") format
The event swum as "100 Fly", "200 IM", "400
Free", "50 Back", "200 Breast" etc.
The course in which the time was swum as "LCM",
"SCM" or "SCY"
The course to convert the time to as "LCM",
"SCM" or "SCY"
If TRUE will return a data frame containing columns
Time
Course
Course_To
Event
Time_Converted_sec
Time_Converted_mmss
. If FALSE (the default) will return only a converted time.
course_convert_helper is a helper function inside course_convert