purrr::safely.Used in scrapping, when swim_parse is applied over a list of results using purrr::map the result is a list of two element lists.
The first element is the results, the second element is an error register. This funtion removes all elements where the error register is not NULL,
and then returns the results (first element) of the remaining lists.
discard_errors(x)a list of lists from purrr::map and purrr:safely
a list of lists where elements with an error have been discarded and all error elements have been removed