Locates event labels in text of results output from read_results and their associated row numbers. The resulting dataframe is joined back into results to include event names
Usage
event_parse(text)
Arguments
text
output from read_results followed by add_row_numbers
Value
returns a dataframe with event names and row numbers to eventually be recombined with swimming results inside swim_parse
See Also
event_parse is a helper function inside swim_parse