Learn R Programming

SwimmeR (version 0.6.0)

fill_left: Shifts non-NA values to left in dataframe

Description

Moves non-NA data left into NA spaces, then removes all columns that contain only NA values

Usage

fill_left(df)

Arguments

df

a dataframe having some NA values

Value

a dataframe where all values have been pushed left, replacing NAs, and all columns containing only NAs have been removed

See Also

fill_left is a helper function inside lines_sort