powered by
Fold a vector onto itself
fold(x, block.size = 1)
a vector
the size of groups in which to block the data
a new vector in the following order: first block, last block, second block, second-to-last block, ...
from the seemingly now defunct mRchmadness package by Eli Shayer and Saber Powers and used per the terms of that package's GPL-2 license
mRchmadness