Locates heat labels in text of results output from read_results and
their associated row numbers. The resulting data frame is joined back into
results to include heat numbers
heat_parse_omega(text)returns a data frame with heat names and row numbers to eventually
be recombined with swimming results inside swim_parse_omega
output from read_results followed by
add_row_numbers
heat_parse_omega is a helper function inside
swim_parse_omega