hy3_places: Helper for reading prelims and finals places from Hy-Tek .hy3 files
Description
Used to pull prelims and finals places from .hy3 files as part of parsing them.
Usage
hy3_places(
file,
type = c("prelims", "relay_prelims", "finals", "relay_finals")
)Value
a data frame where column 1 is times and column 2 is row number
Arguments
- file
an output of read_results, from an .hy3 file
- type
type of times, either "prelims", "relay_prelims", "finals" or "relay_finals"
See Also
hy3_places is run inside of hy3_parse