Learn R Programming

SwimmeR (version 0.5.0)

interleave_results: Helper for reading interleaving prelims and finals results

Description

Interleaves times or places based on row number ranges.

Usage

interleave_results(entries, results, type = c("individual", "relay"))

Arguments

entries

a dataframe containing columns for minimum and maximum row number (usually `Row_Min` and `Row_Max`). Times or places will be interleaved into this dataframe.

results

a dataframe containing times (or places) in column 1 (or other values to be interleaved) and row numbers in column 2 (usually `Row_Numb`).

type

either "individual" or "relay"

Value

a modified version of `entries` with values from `results` interleaved on the basis of row number

See Also

interleave_results is a helper function used in parse_hy3