is_link_broken: Determines if a link is valid
Description
Used in testing links to external data, specifically inside of internal package tests.
Attempts to connect to link for the length of duration (in s). If it fails it returns FALSE
Usage
is_link_broken(link_to_test, duration = 1)
Value
TRUE if the link works, FALSE if it fails