Learn R Programming

SwimmeR (version 0.6.0)

lines_sort: Sorts and collects lines by performance and row number

Description

Collects all lines, (for example containing splits or relay swimmers) associated with a particular performance (a swim) into a dataframe with the appropriate row number for that performance

Usage

lines_sort(x, min_row = minimum_row)

Arguments

x

a list of character strings including performances, with tow numbers added by add_row_numbers

min_row

the lowest row number

Value

a dataframe with Row_Numb as the first column. Other columns are performance elements, like splits or relay swimmers, both in order of occurrence left to right

See Also

lines_sort is a helper function inside splits_parse and swim_parse_ISL