Learn R Programming

SwimmeR (version 0.6.0)

list_transform: Transform list of lists into dataframe

Description

Converts list of lists, with all sub-lists having the same number of elements into a dataframe where each sub-list is a row and each element a column

Usage

list_transform(x)

Arguments

x

a list of lists, with all sub-lists having the same length

Value

a dataframe where each sub-list is a row and each element of that sub-list is a column

See Also

list_transform is a helper function used inside of swim_parse, swim_parse_ISL, event_parse and event_parse_ISL