Takes a numeric item or list of numeric items representing seconds (eg 95.37) and converts to a character string or list of strings in swimming format ("1:35.37").
Usage
mmss_format(x)
Arguments
x
A number of seconds to be converted to swimming format
Value
the number of seconds x converted to conventional swimming format mm:ss.hh
See Also
sec_formatmmss_format is the reverse of sec_format