Helper function used inside `swim_parse` for dealing with Hy-Tek .hy3 files. Can have more columns than other `swim_parse` outputs, because .hy3 files can contain more data
parse_hy3(
file,
avoid = avoid_minimal,
typo = typo_default,
replacement = replacement_default
)output from read_results
a list of strings. Rows in x containing these strings will not be included. For example "Pool:", often used to label pool records, could be passed to avoid. The default is avoid_default, which contains many strings similar to "Pool:", such as "STATE:" and "Qual:". Users can supply their own lists to avoid.
a list of strings that are typos in the original results. swim_parse is particularly sensitive to accidental double spaces, so "Central High School", with two spaces between "Central" and "High" is a problem, which can be fixed. Pass "Central High School" to typo. Unexpected commas as also an issue, for example "Texas, University of" should be fixed using typo and replacement
a list of fixes for the strings in typo. Here one could pass "Central High School" (one space between "Central" and "High") and "Texas" to replacement fix the issues described in typo
returns a dataframe with columns Name, Place, Grade, School, Prelims_Time, Finals_Time, & Event. May also contain Seed_Time, USA_ID, and/or Birthdate. Note all swims will have a Finals_Time, even if that time was actually swam in the prelims (i.e. a swimmer did not qualify for finals). This is so that final results for an event can be generated from just one column.
parse_hy3 must be run on the output of read_results
parse_hy3 runs inside of swim_parse