swim_parseTakes the output of read_results and, inside of swim_parse, extracts split times and associated row numbers
splits_parse(text, split_len = split_length)output of read_results with tow numbers appended by add_row_numbers
length of pool at which splits are measured - usually 25 or 50
returns a dataframe with split times and row numbers
splits_parse runs inside swim_parse on the output of read_results with row numbers from add_row_numbers