swim_parse_splashTakes the output of read_results and, inside of swim_parse_splash,
extracts split times and associated row numbers
splits_parse_splash_relays(text, split_len = split_length_splash)returns a dataframe with split times and row numbers
output of read_results with row numbers appended by
add_row_numbers
length of pool at which splits are measured - usually 25 or 50
splits_parse runs inside swim_parse_splash on the
output of read_results with row numbers from
add_row_numbers