Learn R Programming

SwimmeR (version 0.6.0)

swim_parse_ISL: Formats swimming results from the International Swim League ('ISL') read with read_results into a data frame

Description

Takes the output of read_results and cleans it, yielding a data frame of 'ISL' swimming results

Usage

swim_parse_ISL(file, splits = FALSE, relay_swimmers = FALSE)

Swim_Parse_ISL(file, splits = FALSE, relay_swimmers = FALSE)

Arguments

file

output from read_results

splits

should splits be included, default is FALSE

relay_swimmers

should relay swimmers be included as separate columns, default is FALSE

Value

returns a data frame of ISL results

See Also

swim_parse_ISL must be run on the output of read_results

Examples

Run this code
# NOT RUN {
swim_parse_ISL(
read_results(
"https://isl.global/wp-content/uploads/2019/11/isl_college_park_results_day_2.pdf"),
splits = TRUE,
relay_swimmers = TRUE)
 
# }

Run the code above in your browser using DataLab