swim_place: Adds places to swimming results
Description
Places are awarded on the basis of time, with fastest (lowest) time winning. Ties are placed as ties (both athletes get 2nd etc.)
Usage
swim_place(df, max_place)
Arguments
df
a dataframe with results from swim_parse, including only swimming results (not diving)
max_place
highest place value that scores
Value
df modified so that places have been appended based on swimming time
See Also
swim_place is a helper function used inside of results_score