Learn R Programming

SwimmeR (version 0.3.0)

Read_Results: Reads swimming and diving results into a list of strings in preparation for parsing with Swim_Parse

Description

Outputs list of strings to be processed by Swim_Parse

Usage

Read_Results(file, node = NULL)

read_results(file, node = NULL)

Arguments

file

a .pdf or .html file (could be a url) where containing swimming results. Must be formatted in a "normal" fashion - see vignette

node

a CSS node where html results are stored. Required for html results.

Value

returns a list of strings containing the information from x. Should then be parsed with Swim_Parse

See Also

Read_Results is meant to be followed by Swim_Parse

Examples

Run this code
# NOT RUN {
Read_Results("http://www.nyhsswim.com/Results/Boys/2008/NYS/Single.htm", node = "pre")
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab