Locates event labels in text of 'ISL' results output from read_results and their associated row numbers. The resulting dataframe is joined back into results to include event names
event_parse_ISL(text)output from read_results followed by add_row_numbers
returns a dataframe with event names and row numbers to eventually be recombined with swimming results inside swim_parse_ISL
event_parse_ISL is a helper function inside swim_parse_ISL