powered by
Moves non-NA data left into NA spaces, then removes all columns that contain only NA values
fill_left(df)
a dataframe having some NA values
a dataframe where all values have been pushed left, replacing NAs, and all columns containing only NAs have been removed
fill_left is a helper function inside lines_sort
fill_left
lines_sort