Interleaves times or places based on row number ranges.
interleave_results(entries, results, type = c("individual", "relay"))a dataframe containing columns for minimum and maximum row number (usually `Row_Min` and `Row_Max`). Times or places will be interleaved into this dataframe.
a dataframe containing times (or places) in column 1 (or other values to be interleaved) and row numbers in column 2 (usually `Row_Numb`).
either "individual" or "relay"
a modified version of `entries` with values from `results` interleaved on the basis of row number
interleave_results is a helper function used in parse_hy3