Collects all lines, (for example containing splits or relay swimmers) associated with a particular performance (a swim) into a dataframe with the appropriate row number for that performance
lines_sort(x, min_row = minimum_row)a list of character strings including performances, with tow numbers added by add_row_numbers
the lowest row number
a dataframe with Row_Numb as the first column. Other columns are performance elements, like splits or relay swimmers, both in order of occurrence left to right
lines_sort is a helper function inside splits_parse and swim_parse_ISL