Used in testing the workings for split_parse inside test-splits.R.
Note that even properly handled splits may not match the finals time due to issues in the source material.
Sometimes splits aren't fully recorded in the source.
Some relays also will not match due to the convention of reporting splits by swimmer (see vignette for more details).
splits_reform(df)a dataframe output from swim_parse creates with splits = TRUE
a dataframe with a column not_matching containing TRUE if the splits for that swim match the finals time and FALSE if they do not