powered by
read_results
Takes the output of read_results and cleans it, yielding a dataframe of 'ISL' swimming results
swim_parse_ISL(file)Swim_Parse_ISL(file)
Swim_Parse_ISL(file)
output from read_results
returns a dataframe with columns Place, Lane, Name, Team, Time, Points, Event and DQ.
Place
Lane
Name
Team
Time
Points
Event
DQ
swim_parse_ISL must be run on the output of read_results
swim_parse_ISL
# NOT RUN { swim_parse_ISL( read_results( "https://isl.global/wp-content/uploads/2019/11/isl_college_park_results_day_2.pdf")) # }
Run the code above in your browser using DataLab